<?php namespace prlbr\aneamal\mathjaxcdn;

/* Function include_mathjax
*
*  This function references the files necessary to let the MathJax software
*  convert mathematical expressions written in TeX and elements added by the
*  American Mathematical society into a beautiful output. The configuration
*  takes place here as well.
*
*  return value:  HTML + JavaScript code
*  return type:   string
*/
return function (array $_) {

	list ($expression, $style) = $_;

	// MathJax only needs to be included once, which is checked by looking for
	// a static variable $included
	static $included = false;

	if ($included):
		$mathjax = '';
	else:
		// the class 'tex2jax_ignore' is added to the body, which makes MathJax
		// ignore everything except regions with the class 'tex2jax_process'
		// that we add later to math content
		$preps = "<script>document.body.classList.add('tex2jax_ignore');</script>";
		
		// MathJax is loaded from the content delivery network (CDN) recommended
		// by MathJax here: https://www.mathjax.org/cdn-shutting-down/
		// Note that MathJax shut down a CDN that was previously recommended and
		// there is no guarantee that the new one will not be shut down, too.
		// But you can host MathJax on your own server to be in full control.
		// See: http://docs.mathjax.org/en/latest/installation.html
		$source = 'https://cdn.jsdelivr.net/npm/mathjax@2.7.8/MathJax.js?config=TeX-AMS_SVG-full';

		// set up MathJax
		$options = '<script type="text/x-mathjax-config">MathJax.Hub.Config ({jax: ["input/TeX", "output/SVG"], extensions: ["tex2jax.js"], messageStyle: "none", showMathMenu: false, showMathMenuMSIE: false, showProcessingMessages: false, SVG: {blacker: 1.1, font: "TeX", scale: 90}, tex2jax: {displayMath: [["$$","$$"]], inlineMath: [["$","$"]], ignoreClass: "tex2jax_ignore", processClass: "tex2jax_process", processEnvironments: false, processRefs: false}});</script>';

		// return the options and including code; this order is significant
		$mathjax = $preps . $options . "<script type='text/javascript' src='$source'></script>";

		$included = true;
	endif;

	if ($style === 'text'):
		return $mathjax . "<span class='tex2jax_process'>$" . htmlspecialchars (trim ($expression), ENT_SUBSTITUTE, 'UTF-8') . '$</span>';
	else:
		return $mathjax . "<div class='tex2jax_process'>$$" . htmlspecialchars (trim ($expression), ENT_SUBSTITUTE, 'UTF-8') . '$$</div>';
	endif;
};

// Last changed: 2020L05